==> ejc-assistrmat-api-3.0.0-20220414.072734-71-sources.jar: com/ejianc/business/assist/rmat/vo/record/RelieveRecordVO.java <==
package com.ejianc.business.assist.rmat.vo.record;

import com.ejianc.business.assist.rmat.vo.ContractRelieveVO;

import java.util.ArrayList;
import java.util.List;

public class RelieveRecordVO {

    private static final long serialVersionUID = 1L;

    /**
     * 主键
     */
    private Long id;
    
    /**
     * 主合同主键
     */
    private Long mainContractId;
    
    /**
     * 合同履约状态：0-未签订，1-履约中，2-已封账，3-已解除，4-已冻结
     */
    private String contractStatus;
    
    /**
     * 变更状态(1-未变更 2-变更中 3-已变更)
     */
    private Integer changeStatus;

    /**
     * 签章状态：0-未签章，1-待乙方签章，2-待甲方签章，3-已签章
     */
    private Integer signatureStatus;
    
    private List<ContractRelieveVO> detailList = new ArrayList<>();


    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public Long getMainContractId() {
        return mainContractId;
    }

    public void setMainContractId(Long mainContractId) {
        this.mainContractId = mainContractId;
    }
    

    public String getContractStatus() {
        return contractStatus;
    }

    public void setContractStatus(String contractStatus) {
        this.contractStatus = contractStatus;
    }

    public Integer getChangeStatus() {
        return changeStatus;
    }

    public void setChangeStatus(Integer changeStatus) {
        this.changeStatus = changeStatus;
    }

    public Integer getSignatureStatus() {
        return signatureStatus;
    }

    public void setSignatureStatus(Integer signatureStatus) {
        this.signatureStatus = signatureStatus;
    }

    public List<ContractRelieveVO> getDetailList() {
        return detailList;
    }

    public void setDetailList(List<ContractRelieveVO> detailList) {
        this.detailList = detailList;
    }
}

==> ejc-assistrmat-api-3.0.0-20221101.020733-293-sources.jar: com/ejianc/business/assist/rmat/vo/record/RelieveRecordVO.java <==
package com.ejianc.business.assist.rmat.vo.record;

import com.ejianc.business.assist.rmat.vo.ContractRelieveVO;

import java.util.ArrayList;
import java.util.List;

public class RelieveRecordVO {

    private static final long serialVersionUID = 1L;

    /**
     * 主键
     */
    private Long id;
    
    /**
     * 主合同主键
     */
    private Long mainContractId;
    
    /**
     * 合同履约状态：1-未签订，2-履约中，3-已终止，4-已作废，5-已冻结，6-已结束
     */
    private String performanceStatus;
    
    /**
     * 变更状态(1-未变更 2-变更中 3-已变更)
     */
    private Integer changeStatus;

    /**
     * 签章状态：0-未签章，1-待乙方签章，2-待甲方签章，3-已签章
     */
    private Integer signatureStatus;
    
    private List<ContractRelieveVO> detailList = new ArrayList<>();


    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public Long getMainContractId() {
        return mainContractId;
    }

    public void setMainContractId(Long mainContractId) {
        this.mainContractId = mainContractId;
    }
    
    public String getPerformanceStatus() {
        return performanceStatus;
    }

    public void setPerformanceStatus(String performanceStatus) {
        this.performanceStatus = performanceStatus;
    }

    public Integer getChangeStatus() {
        return changeStatus;
    }

    public void setChangeStatus(Integer changeStatus) {
        this.changeStatus = changeStatus;
    }

    public Integer getSignatureStatus() {
        return signatureStatus;
    }

    public void setSignatureStatus(Integer signatureStatus) {
        this.signatureStatus = signatureStatus;
    }

    public List<ContractRelieveVO> getDetailList() {
        return detailList;
    }

    public void setDetailList(List<ContractRelieveVO> detailList) {
        this.detailList = detailList;
    }
}
